//
//  SMSSuddenMotionSensor.h
//  Sudden Motion Sensor
//
//  Created by Georg C. on 02.08.08.
//  Copyright 2008 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>


typedef enum {
	SMSUnknownHardware				= 0,
	SMSHardware_PowerBook			= 1,
	SMSHardware_iBook					= 2,
	SMSHardware_HighResPowerBook	= 3,
	SMSHardware_MacBookPro			= 4
} SMSHardwareType;


@class SMSSuddenMotionSensor;


@protocol SMSSuddenMotionSensorDelegate <NSObject>

@optional
- (void)suddenMotionSensorDidDetectMovement:(SMSSuddenMotionSensor *)theSensor x:(double)theDeltaX y:(double)theDeltaY z:(double)theDeltaZ;
- (void)suddenMotionSensorDidDetectStartOfMovement:(SMSSuddenMotionSensor *)theSensor;
- (void)suddenMotionSensorDidDetectStopOfMovement:(SMSSuddenMotionSensor *)theSensor;

@end


@interface SMSSuddenMotionSensor : NSObject {
	SMSHardwareType									hardwareType;
	double												sensitivity;
	NSTimeInterval										pollingInterval;
	NSTimer												*pollingTimer;
	NSUInteger											startCount;
	struct {
		BOOL					areAvailable;
		double				x;
		double				y;
		double				z;
	} averageSuddenMotionSensorValues;
	BOOL													wasMovingBefore;
	__weak id<SMSSuddenMotionSensorDelegate>	delegate;
}

@property(readwrite, assign)	SMSHardwareType									hardwareType;
@property(readwrite, assign)	double												sensitivity;
@property(readwrite, assign)	NSTimeInterval										pollingInterval;
@property(readonly, assign,
	getter=isDetectingMovements)	BOOL												detectingMotions;
@property(readwrite, assign)	__weak id<SMSSuddenMotionSensorDelegate>	delegate;

- (id)init;
- (id)initWithHardwareType:(SMSHardwareType)theHardwareType;

+ (SMSSuddenMotionSensor *)sensorWithSensitivity:(double)theSensitivity delegate:(id<SMSSuddenMotionSensorDelegate>)theDelegate;
+ (BOOL)suddenMotionSensorSupported;

+ (BOOL)readRawX:(int *)theXP y:(int *)theYP z:(int *)theZP withHardwareType:(SMSHardwareType)theHardwareType;
+ (BOOL)readX:(int *)theXP y:(int *)theYP z:(int *)theZP withHardwareType:(SMSHardwareType)theHardwareType;
+ (BOOL)readRealX:(double *)theXP y:(double *)theYP z:(double *)theZP withHardwareType:(SMSHardwareType)theHardwareType;

- (void)startDetectingMovements;
- (void)stopDetectingMovements;

@end
