//
//  WMInfringementSensor.h
//  Watchmac
//
//  Created by Georg C. on 26.10.08.
//  Copyright 2008 bloo7 (Georg C. Brückmann). All rights reserved.
#import "WMPlugIn.h"


@class WMInfringement;
@class WMInfringementSensor;
@class WMInfringementSensorDefaults;


@protocol WMInfringementSensorDelegate <NSObject>

- (void)sensor:(WMInfringementSensor *)theSensor didDetectInfringement:(WMInfringement *)theInfringement;

@end


@interface WMInfringementSensor : WMPlugIn {
	id<WMInfringementSensorDelegate>	delegate;
	NSMutableSet							*observedInfringementNames;
	NSMutableDictionary					*userDefaults;
}

@property(readwrite, assign)	id<WMInfringementSensorDelegate>	delegate;
@property(readonly, assign,
	getter=isStarted)				BOOL								started;
@property(readonly, copy)		NSSet								*observedInfringementNames;
/* Info.plist: WMDetectableInfringementNames */
@property(readonly, copy)		NSSet								*detectableInfringementNames;

- (id)initWithBundle:(NSBundle *)theBundle plugInManager:(id)theManager;

- (BOOL)startDetectingInfringement:(NSString *)theInfringementName withOptions:(id)theOptions delegate:(id<WMInfringementSensorDelegate>)theDelegate;
- (BOOL)stopDetectingInfringement:(NSString *)theInfringementName;

- (NSImage *)iconForInfringementName:(NSString *)theInfringementName;
- (NSString *)localizedInfringementName:(NSString *)theName;
- (NSString *)localizedDescriptionForInfringementName:(NSString *)theInfringementName;
- (NSString *)localizedExplanatoryMessageForInfringement:(WMInfringement *)theInfringement;

- (void)notifyDelegateOfInfringement:(WMInfringement *)theInfringement;

- (WMViewController *)optionsViewControllerForInfringementName:(NSString *)theName;

- (WMInfringementSensorDefaults *)userDefaultsForInfringementName:(NSString *)theInfringementName;

- (BOOL)migrateUserDefaults:(WMInfringementSensorDefaults *)theDefaults;

@end
