//
//  WMReaction.h
//  Watchmac
//
//  Created by Georg C. on 26.10.08.
//  Copyright 2008 bloo7 (Georg C. Brückmann). All rights reserved.
#import "WMPlugIn.h"


@class WMRecordedInfringement;
@class WMReaction;
@class WMReactionDefaults;
@class WMViewController;


@protocol WMReactionDelegate <NSObject>

- (void)reaction:(WMReaction *)theReaction didEndSuccessfully:(BOOL)success;

- (NSUInteger)declareWaitCondition:(id)theCondition;
- (BOOL)fulfillWaitCondition:(id)theCondition;

@end


@interface WMReaction : WMPlugIn {
	id<WMReactionDelegate>	delegate;
	WMViewController			*reactionOptionsViewController;
	NSMutableDictionary		*userDefaults;
	WMReactionDefaults		*globalUserDefaults;
	WMRecordedInfringement	*infringement;
	NSImage						*reactionIcon;
}

@property(readwrite, assign)	id<WMReactionDelegate>	delegate;
@property(readonly, copy)		NSString						*localizedDescription;
@property(readonly, copy)		NSString						*localizedReactionName;
@property(readonly, retain)	WMViewController			*reactionOptionsViewController;
@property(readonly, assign)	NSInteger					priority;
@property(readonly, assign)	NSImage						*reactionIcon;
@property(readwrite, retain)	WMRecordedInfringement	*infringement;

- (id)initWithBundle:(NSBundle *)theBundle plugInManager:(id)theManager;

- (BOOL)prepareReactingToInfringement:(WMRecordedInfringement *)theInfringement withOptions:(id)theOptions;
/* -beginReactingToInfringement:withOptions: will detach a background thread for the
	actual reaction logic. */
- (BOOL)beginReactingToInfringement:(WMRecordedInfringement *)theInfringement withOptions:(id)theOptions;
/* -reactToInfringement:withOptions: is where you will implement the actual reaction logic.
	NOTE: This method may be called on a background thread. */
- (BOOL)reactToInfringement:(WMRecordedInfringement *)theInfringement withOptions:(id)theOptions;

- (WMReactionDefaults *)userDefaultsForInfringementName:(NSString *)theInfringementName;
@property(readonly, retain)	WMReactionDefaults	*globalUserDefaults;

@end
